@@ -23,9 +23,6 @@
 
 #include <QtCore/QList>
 
-#include <boost/graph/adjacency_list.hpp>
-#include <boost/graph/topology.hpp>
-
 #include "rocslib_export.h"
 #include "Rocs_Typedefs.h"
 
